// Copyright 2022 schukai GmbH
// SPDX-License-Identifier: AGPL-3.0

package configuration

import (
	"github.com/stretchr/testify/assert"
	"os"
	"testing"
)

type Issue17Struct struct {
	P1 *BoolValue `json:"p1" yaml:"p1"`
	P2 *BoolValue `json:"p2" yaml:"p2"`
}

func createIssue17TempFile(content string) (string, error) {
	file, err := os.CreateTemp("", "tempfile")
	if err != nil {
		return "", err
	}
	defer func() {
		_ = file.Close()
	}()

	_, err = file.WriteString(content)
	if err != nil {
		return "", err
	}

	return file.Name(), nil
}

func TestIssue17LoadBool(t *testing.T) {

	c := New(Issue17Struct{})

	n, err := createIssue17TempFile(`
p1: true
p2: off
`)

	if err != nil {
		t.Fatal(err)
	}

	c.SetMnemonic("my-app")
	c.AddFile(n)
	c.Import()

	_ = os.Remove(n)

	if c.errors != nil {
		t.Fatal(c.errors)
	}

	assert.Equal(t, "true", c.Config().P1.String())
	assert.Equal(t, true, c.Config().P1.IsTrue())

	assert.Equal(t, "false", c.Config().P2.String())
	assert.Equal(t, false, c.Config().P2.IsTrue())

}
