// Copyright 2022 schukai GmbH
// SPDX-License-Identifier: AGPL-3.0

package configuration

import (
	"gitlab.schukai.com/oss/libraries/go/utilities/watch.git"
	"path"
)

func (s *Settings[C]) StopWatching() *Settings[C] {

	if s.fileWatch != nil {
		err := s.fileWatch.StopWatching()
		if err != nil {
			s.errors = append(s.errors, err)
			return s
		}
	}

	// remove all files from watch list
	for _, f := range s.files.files {
		d := path.Dir(f.path)
		err := s.fileWatch.Remove(d)
		if err != nil {
			s.errors = append(s.errors, err)
		}
	}

	for _, d := range s.files.directories {
		err := s.fileWatch.Remove(d)
		if err != nil {
			s.errors = append(s.errors, err)
		}
	}

	return s
}

// Watch the given file for changes
func (s *Settings[C]) Watch() *Settings[C] {

	if s.fileWatch == nil {
		s.fileWatch = watch.NewLighthouse()
	}

	err := s.fileWatch.StartWatching()
	if err != nil {
		s.errors = append(s.errors, err)
		return s
	}

	for _, d := range s.files.directories {

		w := &watch.Watch{
			Path: d,
			OnChange: func(x string) {
				if x == d {
					s.Import()
				}
			},
		}

		err := s.fileWatch.Add(w)
		if err != nil {
			s.errors = append(s.errors, err)
		}
	}

	for _, f := range s.files.files {

		p := path.Dir(f.path)

		w := &watch.Watch{
			Path: p,
			OnChange: func(x string) {
				if x == f.path {
					s.Import()
				}

			},
		}

		err := s.fileWatch.Add(w)
		if err != nil {
			s.errors = append(s.errors, err)
		}
	}

	return s

}
